"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MathRecord = void 0;
const errors_1 = require("../util/errors");
const db_1 = require("../util/db");
const uuid_1 = require("uuid");
const bcrypt_1 = require("bcrypt");
const EmailValidator = __importStar(require("email-validator"));
class MathRecord {
    constructor(obj) {
        var _a, _b, _c, _d;
        if (!obj.nick || obj.nick.length > 24) {
            throw new errors_1.ValidationError("Nick nie może być pusta nazwa, ani nie może przekraczać 24 znaków.");
        }
        if (!obj.pass || obj.pass.length < 6) {
            throw new errors_1.ValidationError("Hasło nie może być pusta nazwa, ani nie może być krótsze niż 6 znaków.");
        }
        if (!(EmailValidator.validate(obj.email))) {
            throw new errors_1.ValidationError("To nie jest poprawny email!");
        }
        this.id = obj.id;
        this.nick = obj.nick;
        this.pass = obj.pass;
        this.email = obj.email;
        this.add = (_a = obj.add) !== null && _a !== void 0 ? _a : 0;
        this.sub = (_b = obj.sub) !== null && _b !== void 0 ? _b : 0;
        this.mul = (_c = obj.mul) !== null && _c !== void 0 ? _c : 0;
        this.div = (_d = obj.div) !== null && _d !== void 0 ? _d : 0;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT * FROM `math` WHERE `id` = :id', {
                id
            });
            return results.length === 0 ? null : new MathRecord(results[0]);
        });
    }
    ;
    static checkNick(nick) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT * FROM `math` WHERE `nick` = :nick', {
                nick
            });
            return results.length === 0;
        });
    }
    ;
    static checkLog(nick, passLog) {
        return __awaiter(this, void 0, void 0, function* () {
            const falseNick = yield MathRecord.checkNick(nick);
            if (falseNick) {
                throw new errors_1.ValidationError("Taki nick nie istnieje");
            }
            else {
                const [[{ pass, id }]] = yield db_1.pool.execute('SELECT `pass`, `id` FROM `math` WHERE `nick` = :nick', {
                    nick
                });
                const isTruePass = yield (0, bcrypt_1.compare)(passLog, pass);
                return isTruePass ? id : '';
            }
        });
    }
    ;
    static findAll(name) {
        return __awaiter(this, void 0, void 0, function* () {
            let sqlStr;
            switch (name) {
                case 'add':
                    sqlStr = "SELECT * FROM `math` ORDER BY `add` DESC";
                    break;
                case 'sub':
                    sqlStr = "SELECT * FROM `math` ORDER BY `sub` DESC";
                    break;
                case 'mul':
                    sqlStr = "SELECT * FROM `math` ORDER BY `mul` DESC";
                    break;
                case 'div':
                    sqlStr = "SELECT * FROM `math` ORDER BY `div` DESC";
                    break;
                case 'nick':
                default:
                    sqlStr = "SELECT * FROM `math` ORDER BY `nick` ASC";
            }
            const [results] = yield db_1.pool.execute(sqlStr);
            return results.map(result => {
                const { nick, add, sub, mul, div } = result;
                return { nick, add, sub, mul, div };
            });
        });
    }
    static getOneRes(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [[results]] = yield db_1.pool.execute('SELECT `add`, `sub`, `mul`, `div` FROM `math` WHERE `id` = :id', {
                id
            });
            return results;
        });
    }
    ;
    static addPoints(id, name, val) {
        return __awaiter(this, void 0, void 0, function* () {
            const ent = yield MathRecord.getOneRes(id);
            yield db_1.pool.execute("UPDATE `math` SET  `add` = :add, `sub` = :sub, `mul` = :mul, `div` = :div WHERE `id` = :id", {
                id,
                add: name === 1 ? ent.add + val : ent.add,
                sub: name === 2 ? ent.sub + val : ent.sub,
                mul: name === 3 ? ent.mul + val : ent.mul,
                div: name === 4 ? ent.div + val : ent.div,
            });
            return true;
        });
    }
    ;
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (yield MathRecord.checkNick(this.nick)) {
                if (!this.id) {
                    this.id = (0, uuid_1.v4)();
                    const val = yield (0, bcrypt_1.hash)(this.pass, 10);
                    yield db_1.pool.execute("INSERT INTO `math` (`id`, `nick`, `pass`, `add`, `sub`, `mul`, `div`, `email`) VALUES (:id, :nick, :pass, :add, :sub, :mul, :div, :email)", {
                        id: this.id,
                        nick: this.nick,
                        pass: val,
                        add: this.add,
                        sub: this.sub,
                        mul: this.mul,
                        div: this.div,
                        email: this.email,
                    });
                }
                else {
                    throw new errors_1.ValidationError("Takie id juz istnieje");
                }
            }
            else {
                throw new errors_1.ValidationError("Taki nick juz istnieje");
            }
        });
    }
    ;
}
exports.MathRecord = MathRecord;
//# sourceMappingURL=math.record.js.map